QUARTER_OR_WAVE_OPTION = """Para bases de datos hasta 2003, el tipo de frecuencia (freq) debe ser 'onda'
Para bases de datos desde 2004, el tipo de frecuencia (freq) debe ser 'trimestre'"""

INDEC_2007_3 = """INDEC advierte: La informacion correspondiente al tercer trimestre 
2007 no esta disponible ya que los aglomerados Mar del Plata-Batan, 
Bahia Blanca-Cerri y Gran La Plata no fueron relevados por causas 
de orden administrativo, mientras que los datos correspondientes al 
Aglomerado Gran Buenos Aires no fueron relevados por paro del 
personal de la EPH."""

INDEC_STATS_EMERGENCY = """En el marco de la emergencia estadistica el INDEC no publico la base solicitada. 
Mas informacion en: https://www.indec.gob.ar/ftp/cuadros/sociedad/anexo_informe_eph_23_08_16.pdf"""

INDEC_2007_2015 = """INDEC advierte:
Advertencia sobre el uso de series estadisticas. Se advierte que las series estadisticas publicadas con
posterioridad a enero del 2007 y hasta diciembre 2015 deben ser consideradas con reservas,
excepto las que ya hayan sido revisadas en 2016 y su difusion lo consigne expresamente.
El INDEC, en el marco de las atribuciones conferidas por los decretos 181/15 y 55/16, dispuso las investigaciones
requeridas para establecer la regularidad de procedimientos de obtencion de datos, su procesamiento, elaboracion de indicadores y difusion
Mas informacion en: https://www.indec.gob.ar/ftp/cuadros/sociedad/anexo_informe_eph_23_08_16.pdf"""
